;; Generated package description from urgrep.el  -*- no-byte-compile: t -*-
(define-package "urgrep" "0.5.3snapshot0.20250701.205050" "Universal recursive grep" '((emacs "27.1") (compat "29.1.0.1") (project "0.3.0")) :commit "92bcc1d8e30da62a67287e58c732fe5b9373b22f" :keywords '("grep" "search") :url "https://github.com/jimporter/urgrep")
